=======
History
=======

0.2.0
-----

* Refactoring of `ravenpy.utilities.testdata` functions
* Bump xclim to 0.23

0.1.7
-----

* Fix xarray caching bug affecting climatological ESP forecasts (#33)
* Fix deprecation issue with Fiona

0.1.6 (2021-01-15)
------------------

* Correct installer bugs

0.1.5 (2021-01-14)
------------------

* Release with docs


0.1.0 (2020-12-20)
------------------

* First release on PyPI
